Represents a price level in the order book with associated order details.
Summary
Types
@type side() :: :bid | :ask
@type t() :: %Rujira.Fin.Book.Price{ price: Decimal.t(), side: side(), total: Rujira.Amount.t(), value: Rujira.Amount.t() }
Represents a price level in the order book with associated order details.
@type side() :: :bid | :ask
@type t() :: %Rujira.Fin.Book.Price{ price: Decimal.t(), side: side(), total: Rujira.Amount.t(), value: Rujira.Amount.t() }